@@ -2,7 +2,7 @@
 
 #define QT_FEATURE_webengine_system_alsa 1
 
-#define QT_FEATURE_webengine_v8_snapshot_support 1
+#define QT_FEATURE_webengine_v8_context_snapshot 1
 
 #define QT_FEATURE_webengine_system_pulseaudio 1
 
@@ -22,5 +22,9 @@
 
 #define QT_FEATURE_webengine_sanitizer -1
 
+#define QT_FEATURE_webengine_vulkan 1
+
+#define QT_FEATURE_webengine_vaapi 1
+
 #define QT_FEATURE_webengine_system_poppler -1
 
